CheckFireStore class

Constructors

CheckFireStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String docId) Future<Check?>
getObjectReference() → CollectionReference<Check>
insertBulk(List<Check> objects) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(Check object) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited